@@ -20,6 +20,9 @@ def add_info(report, ui):
     if response:
         report.setdefault('Tags', 'dist-upgrade')
         report['Tags'] += ' dist-upgrade'
+        attach_file_if_exists(report,
+            '/var/log/dist-upgrade/apt-clone_system_state.tar.gz',
+            'VarLogDistupgradeAptclonesystemstate.tar.gz')
         attach_file_if_exists(report, '/var/log/dist-upgrade/apt.log',
             'VarLogDistupgradeAptlog')
         attach_file_if_exists(report, '/var/log/dist-upgrade/apt-term.log',
