@@ -3,15 +3,19 @@
 set -e
 
 # update demotions
-(cd utils && ./demotions.py natty oneiric > demoted.cfg)
+(cd utils && ./demotions.py oneiric precise > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
-#(cd utils && ./demotions.py hardy lucid > demoted.cfg.hardy)
+(cd utils && ./demotions.py lucid precise > demoted.cfg.lucid)
 
 # update base-installer
 (cd utils && ./update-base-installer.sh)
 
 # update apt_btrfs_snapshot.py copy, this nees a installed
 # apt-btrfs-snapshot on the build machine
+if [ ! -e /usr/share/pyshared/apt_btrfs_snapshot.py ]; then
+    echo "please sudo apt-get install apt-btrfs-snapshot"
+    exit 1
+fi
 cp /usr/share/pyshared/apt_btrfs_snapshot.py DistUpgrade
 
 # (auto) generate the required html
